@@ -1,10 +1,11 @@
 package HTML::TreeBuilder::LibXML;
 use strict;
 use warnings;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 use Carp ();
 use base 'HTML::TreeBuilder::LibXML::Node';
 use XML::LibXML;
+use 5.008001;
 
 sub new {
     my $class = shift;
@@ -86,6 +87,9 @@ sub replace_original {
     return;
 }
 
+# The HTML::TreeBuilder has this method and it is needed to us for web-scraper module
+sub store_comments { }
+
 package # hide from cpan
     HTML::TreeBuilder::LibXML::Destructor;
 
